moviepy.video.fx.all.fadein — MoviePy 1.0.1 documentation

# moviepy.video.fx.all.fadein

`moviepy.video.fx.all.` `fadein`(clip, duration, initial_color=None)

  Makes the clip progressively appear from some color (black by default), over `duration` seconds at the beginning of the clip. Can be used for masks too, where the initial color must be a number between 0 and 1. For cross-fading (progressive appearance or disappearance of a clip over another clip, see `composition.crossfade`